Getting Started
===============

The stable version of ``sospice`` will be available through PyPI via ``pip``,

.. code-block:: shell

   pip install sospice


You can also install the development version from Github,

.. code-block:: shell

   https://github.com/solo-spice/sospice.git
   cd sospice
   pip install -e .

If you will be developing ``sospice``, please see the :ref:`dev-guide`.
